=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2006-12-21 18:07:52 +0000
+++ bzrlib/errors.py	2006-12-21 19:14:35 +0000
@@ -319,6 +319,23 @@
     _fmt = "File exists: %(path)r%(extra)s"
 
 
+class FilesExist(PathError):
+    
+    _fmt = "File(s) exist: %(paths_as_string)s%(extra)s"
+
+    # used when reporting that files do exist
+
+    def __init__(self, paths, extra=None):
+        # circular import
+        from bzrlib.osutils import quotefn
+        BzrError.__init__(self)
+        self.paths = paths
+        self.paths_as_string = ' '.join([quotefn(p) for p in paths])
+        if extra:
+            self.extra = ': ' + str(extra)
+        else:
+            self.extra = ''
+
 class NotADirectory(PathError):
 
     _fmt = "%(path)r is not a directory %(extra)s"
@@ -501,8 +518,29 @@
         self.repo_format = repo_format
 
 
+class AlreadyVersionedError(BzrError):
+    #Used when a path is expected not to be versioned, but it is.
+    
+    _fmt = "%(contextInfo)s%(path)s is already versioned"
+
+    def __init__(self, path, contextInfo=None):
+        """Construct a new NotVersionedError.
+
+        :param path: This is the path which is versioned, 
+        which should be in a user friendly form.
+        :param contextInfo: If given, this is information about the context,
+        which could explain why this is expected to not be versioned.
+        """
+        BzrError.__init__(self)
+        self.path = path
+        if contextInfo is None:
+            self.contextInfo = ''
+        else:
+            self.contextInfo = contextInfo + ": "
+
+
 class NotVersionedError(BzrError):
-    #Used when a path is expected to be versioned, but is it is not.
+    #Used when a path is expected to be versioned, but it is not.
     
     _fmt = "%(contextInfo)s%(path)s is not versioned"
 
@@ -536,17 +574,21 @@
 
 class PathsDoNotExist(BzrError):
 
-    _fmt = "Path(s) do not exist: %(paths_as_string)s"
+    _fmt = "Path(s) do not exist: %(paths_as_string)s%(extra)s"
 
     # used when reporting that paths are neither versioned nor in the working
     # tree
 
-    def __init__(self, paths):
+    def __init__(self, paths, extra=None):
         # circular import
         from bzrlib.osutils import quotefn
         BzrError.__init__(self)
         self.paths = paths
         self.paths_as_string = ' '.join([quotefn(p) for p in paths])
+        if extra:
+            self.extra = ': ' + str(extra)
+        else:
+            self.extra = ''
 
 
 class BadFileKindError(BzrError):

=== modified file 'bzrlib/tests/blackbox/test_mv.py'
--- bzrlib/tests/blackbox/test_mv.py	2006-12-21 18:07:52 +0000
+++ bzrlib/tests/blackbox/test_mv.py	2006-12-21 19:14:35 +0000
@@ -171,7 +171,7 @@
     
         os.remove('a')
         self.run_bzr_error(
-            ["^bzr: ERROR: can't rename: new name .* is already versioned$"],
+            ["^bzr: ERROR: Invalid move destination: .* is already versioned$"],
             'mv', 'a', 'b')
         self.failIfExists('a')
         self.failUnlessExists('b')
@@ -245,8 +245,8 @@
         tree.commit('initial commit')
 
         self.run_bzr_error(
-            ["^bzr: ERROR: can't rename: both, old name .* and new name .*"
-             " exist. Use option '--after' to force rename."],
+            ["^bzr: ERROR: File\(s\) exist: .+ .+: can't rename."
+             " Use option '--after' to force rename."],
             'mv', 'a', 'b')
         self.failUnlessExists('a')
         self.failUnlessExists('b')
@@ -273,8 +273,8 @@
         tree.commit('initial commit')
 
         self.run_bzr_error(
-            ["^bzr: ERROR: can't rename: both, old name .* and new name .*"
-             " exist. Use option '--after' to force rename."],
+            ["^bzr: ERROR: File\(s\) exist: .+ .+: can't rename."
+             " Use option '--after' to force rename."],
             'mv', 'a1', 'a2', 'sub1')
         self.failUnlessExists('a1')
         self.failUnlessExists('a2')

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2006-12-21 18:07:52 +0000
+++ bzrlib/workingtree.py	2006-12-21 19:14:35 +0000
@@ -72,10 +72,11 @@
 
 from bzrlib import symbol_versioning
 from bzrlib.decorators import needs_read_lock, needs_write_lock
-from bzrlib.errors import (BzrCheckError,
+from bzrlib.errors import (AlreadyVersionedError,
+                           BzrCheckError,
                            BzrError,
                            ConflictFormatError,
-                           WeaveRevisionNotPresent,
+                           FilesExist,                     
                            NotADirectory,
                            NotBranchError,
                            NotInWorkingDirectory,
@@ -83,6 +84,7 @@
                            NotVersionedError,
                            MergeModifiedFormatError,
                            UnsupportedOperation,
+                           WeaveRevisionNotPresent,
                            )
 from bzrlib.inventory import InventoryEntry, Inventory, ROOT_ID
 from bzrlib.lockable_files import LockableFiles, TransportLock
@@ -1045,7 +1047,7 @@
         inv = self.inventory
         to_abs = self.abspath(to_dir)
         if not isdir(to_abs):
-            raise NotADirectory(to_abs, extra="(Invalid move destination)")
+            raise NotADirectory(to_abs, extra="Invalid move destination")
         if not self.has_filename(to_dir):
             raise NotInWorkingDirectory(to_dir, extra=
                 "(Invalid move destination)")
@@ -1056,7 +1058,7 @@
             
         to_dir_ie = inv[to_dir_id]
         if to_dir_ie.kind != 'directory':
-            raise NotADirectory(to_abs, extra="(Invalid move destination)")
+            raise NotADirectory(to_abs, extra="Invalid move destination")
 
         # create rename entries and tuples
         for from_rel in from_paths:
@@ -1112,18 +1114,18 @@
 
             # check the inventory for source and destination
             if from_id is None:
-                raise BzrError("can't rename: old name %r is not versioned" % 
-                               from_rel)
+                raise NotVersionedError(path=str(from_rel),
+                    contextInfo="Invalid move source")
             if to_id is not None:
-                raise BzrError("can't rename: new name %r is already"
-                               " versioned" % to_rel)
+                raise AlreadyVersionedError(path=str(to_rel),
+                    contextInfo="Invalid move destination")
 
             # try to determine the mode for rename (only change inv or change 
             # inv and file system)
             if after:
                 if not self.has_filename(to_rel):
-                    raise BzrError("can't rename: new working file %r does not"
-                                   " exist" % to_rel)
+                    raise NoSuchFile(path=str(to_rel),
+                        extra="New file has not been created yet")
                 only_change_inv = True
             elif not self.has_filename(from_rel) and self.has_filename(to_rel):
                 only_change_inv = True
@@ -1133,12 +1135,12 @@
                 # something is wrong, so lets determine what exactly
                 if not self.has_filename(from_rel) and \
                    not self.has_filename(to_rel):
-                    raise BzrError("can't rename: neither old name %r nor new"
-                                   " name %r exist" % (from_rel, to_rel))
+                    raise PathsDoNotExist(paths=(str(from_rel), str(to_rel)),
+                        extra="can't rename")
                 else:
-                    raise BzrError("can't rename: both, old name %r and new"
-                                   " name %r exist. Use option '--after' to"
-                                   " force rename." % (from_rel, to_rel))
+                    raise FilesExist(paths=(str(from_rel), str(to_rel)),
+                        extra="can't rename. Use option '--after' to"
+                              " force rename.")
             rename_entry.only_change_inv = only_change_inv                       
         return rename_entries
 

